compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
@override
int compareTo(LibraryName other) {
for (var index = 0; index < parts.length; index += 1) {
if (other.parts.length <= index) {
return 1;
}
final int result = parts[index].compareTo(other.parts[index]);
if (result != 0) {
return result;
}
}
assert(other.parts.length >= parts.length);
return parts.length - other.parts.length;
}